# Generated by roxygen2: do not edit by hand

export(API_BASE_URL)
export(DEFAULT_POLL_INTERVAL_SECONDS)
export(DEFAULT_POLL_TIMEOUT_SECONDS)
export(DEFAULT_TIMEOUT)
export(SELF_HOSTED_TIMEOUT)
export(clear_synthesize_token)
export(get_example_query)
export(has_synthesize_token)
export(list_models)
export(load_synthesize_token_from_keyring)
export(predict_query)
export(set_synthesize_token)
importFrom(getPass,getPass)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,http_status)
importFrom(httr,status_code)
importFrom(httr,timeout)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(utils,browseURL)
importFrom(utils,modifyList)
