% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/key-handlers.R
\name{load_synthesize_token_from_keyring}
\alias{load_synthesize_token_from_keyring}
\title{Load Synthesize Bio API Token from Keyring}
\usage{
load_synthesize_token_from_keyring()
}
\value{
Invisibly returns TRUE if successful, FALSE if token not found in keyring.
}
\description{
Loads the previously stored Synthesize Bio API token from the system
keyring and sets it in the environment for the current session.
}
\examples{
\dontrun{
# Load token from keyring
load_synthesize_token_from_keyring()
}
}
