% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\docType{data}
\name{DEFAULT_POLL_INTERVAL_SECONDS}
\alias{DEFAULT_POLL_INTERVAL_SECONDS}
\title{Default Poll Interval}
\format{
An object of class \code{numeric} of length 1.
}
\usage{
DEFAULT_POLL_INTERVAL_SECONDS
}
\description{
Default polling interval (seconds) for async model queries
}
\keyword{datasets}
